# Table of Contents

- [sap-discovery-configuring-cloud-alm](<./sap-discovery-configuring-cloud-alm.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Configuring the SAP Cloud ALM Integration](<./Configuring-the-SAP-Cloud-ALM-Integration.md>)
  - [Overview](<./Configuring-the-SAP-Cloud-ALM-Integration/Overview.md>)
  - [Prerequisites](<./Configuring-the-SAP-Cloud-ALM-Integration/Prerequisites.md>)
  - [Step 1: Provision Your Cloud ALM Instance](<./Configuring-the-SAP-Cloud-ALM-Integration/Step-1-Provision-Your-Cloud-ALM-Instance.md>)
  - [Step 2: Generate a Service Key in Your BTP Cockpit](<./Configuring-the-SAP-Cloud-ALM-Integration/Step-2-Generate-a-Service-Key-in-Your-BTP-Cockpit.md>)
  - [Step 3: Connect SAP LeanIX to SAP Cloud ALM](<./Configuring-the-SAP-Cloud-ALM-Integration/Step-3-Connect-SAP-LeanIX-to-SAP-Cloud-ALM.md>)
  - [Additional Capabilities](<./Configuring-the-SAP-Cloud-ALM-Integration/Additional-Capabilities.md>)
  - [Linking Discovered Items to Fact Sheets](<./Configuring-the-SAP-Cloud-ALM-Integration/Linking-Discovered-Items-to-Fact-Sheets.md>)
  - [Viewing Synchronization Logs](<./Configuring-the-SAP-Cloud-ALM-Integration/Viewing-Synchronization-Logs.md>)
